@@ -258,7 +258,7 @@ def get_request():
 
 def round(value):
     value = decimal.Decimal(value)
-    return value.quantize(decimal.Decimal('1.'), rounding=decimal.ROUND_UP)
+    return value.quantize(decimal.Decimal('1.'), rounding=decimal.ROUND_HALF_UP)
 
 
 def human_format(number):
